module.exports = defineTest({
	description: 'merges deprecated with current options',
	command: 'rollup --config rollup.config.js'
});
